style "menubar" 
{
    GtkMenuBar::shadow-type = GTK_SHADOW_NONE
    
    xthickness = 1
    ythickness = 2
    
    engine "murrine"
    {
        contrast = 0.0
        gradient_shades = {1.0, 1.0, 1.0, 1.0}
        highlight_shade = 1.0
        menubarstyle = 0
        #menubaritemstyle = 1
        textstyle = 1
    }
}

style "menubar-menuitem" 
{
    xthickness = 6
    ythickness = 3
    
    bg[PRELIGHT] = @selected_bg_color
    bg[SELECTED] = @bg_color
    fg[PRELIGHT] = @selected_fg_color

    engine "murrine" 
    {
        contrast = .0 
        roundness = 3
        border_shades = { 0.8, 0.8 }
        gradient_shades = {1.0, 1.0, 0.85, 0.85}
        highlight_shade = 1.0
        menubaritemstyle = 1
        textstyle = 1
    }
}

style "menu" 
{
    xthickness = 0
    ythickness = 0

    bg[SELECTED] = @selected_bg_color
    bg[NORMAL] = @base_color
    bg[PRELIGHT] = @selected_bg_color
    bg[ACTIVE] = @base_color
    bg[INSENSITIVE] = @base_color
    fg[NORMAL] = @fg_color # Color for normal text.
    fg[PRELIGHT] = @base_color
    fg[SELECTED] = @base_color
    fg[ACTIVE] = @base_color
    fg[INSENSITIVE] = mix (0.4, @fg_color, @bg_color) # Text color for non-interactive menu items
    text[NORMAL] = @text_color # Color for menu-item radio/checks.
    base[NORMAL] = @bg_color # Color for menu-item radio/checks background.
    text[PRELIGHT] = @base_color
    text[SELECTED] = @base_color
    text[ACTIVE] = @fg_color
    text[INSENSITIVE] = mix (0.4, @fg_color, @bg_color)

    engine "murrine" 
    {
        arrowstyle = 1
        border_shades = {0.8, 0.8}
        gradient_shades = {1.1, 1.1, 0.94, 0.94}
        highlight_shade = 1.0
        menustyle = 0
        roundness = 0 # Roundness of menu items.
        textstyle = 0
    }
}

style "menu-item" 
{
    xthickness = 4
    ythickness = 4

    bg[SELECTED] = shade (0.95, @selected_bg_color)
    bg[PRELIGHT] = shade (0.95, @selected_bg_color)
    fg[PRELIGHT] = @selected_fg_color

    engine "murrine" 
    {
        border_shades = {1.0, 1.0}
        contrast = 0.8
        roundness = 0
        textstyle = 0
    }
}

# This style is there to modify the separator menu items. The goals are:
# 1. Get a specific height.
# 2. The line should go to the edges (ie. no border at the left/right)
style "menu-item-separator" 
{
    GtkSeparatorMenuItem::horizontal-padding = 0
    GtkWidget::wide-separators = 1
    GtkWidget::separator-width = 1
    GtkWidget::separator-height = 7
    
    xthickness = 1
    ythickness = 0
    
    bg[NORMAL] = @base_color # Remove for visible separators.
    
    engine "murrine" 
    {
        contrast = 0.8 # Set the contrast to 0.6 for visible separators.
        separatorstyle = 0
    }
}
