@define-color nemo_sidebar_bg #505050;
@define-color nemo_sidebar_fg #dadada;
@define-color nemo_sidebar_selected_fg #fff;

/********
 * Nemo *
 ********/

/* sidebar */

.nemo-window .sidebar .view {
    background-color: @nemo_sidebar_bg;
    color: @nemo_sidebar_fg;
    text-shadow: none;
    -gtk-icon-shadow: none;
}

.nemo-window .sidebar .view:selected {
    border-color: @nemo_sidebar_bg;
    color: @nemo_sidebar_selected_fg;
    text-shadow: 1px 1px alpha(black, 0.2);
    -gtk-icon-shadow: 1px 1px alpha(black, 0.2);
}

.nemo-window .sidebar .expander:selected {
    border-color: @nemo_sidebar_selected_fg;
    color: @nemo_sidebar_selected_fg;
}

.nemo-window .places-treeview {
    -NemoPlacesTreeView-disk-full-bg-color: shade(@theme_base_color, 0.85);
    -NemoPlacesTreeView-disk-full-fg-color: shade(@theme_selected_bg_color, 0.9);
    -NemoPlacesTreeView-disk-full-bar-width: 2px;
    -NemoPlacesTreeView-disk-full-bar-radius: 1px;
    -NemoPlacesTreeView-disk-full-bottom-padding: 2px;
}

.nemo-window .places-treeview:selected {
    -NemoPlacesTreeView-disk-full-bg-color: shade(@theme_selected_fg_color, 1.1);
    -NemoPlacesTreeView-disk-full-fg-color: @theme_selected_bg_color;
}

.nemo-window .sidebar .scrollbar {
    min-width: 10px;
}

.nemo-window .sidebar scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider {
    background-color: @theme_bg_color;
}

.nemo-window .sidebar separator,
.nemo-window .sidebar .frame {
    border: none;
}

.nemo-canvas-item {
    border-radius: 3px;
}

.nemo-desktop.nemo-canvas-item {
    color: @desktop_item_fg;
    text-shadow: 1px 1px @desktop_item_text_shadow;
}

.nemo-desktop.nemo-canvas-item:selected {
    background-color: alpha(@theme_selected_bg_color, 0.8);
    background-image: none;
    color: @theme_selected_fg_color;
    text-shadow: none;
}

/* inactive pane */

.nemo-inactive-pane .view {
    background-color: shade(@theme_base_color, 0.93);
    color: shade(@theme_fg_color, 1.2);
}

.nemo-inactive-pane .view:selected,
.nemo-inactive-pane .nautilus-canvas-item:selected {
    background-color: alpha(@theme_selected_bg_color, 0.85);
    color: @theme_selected_fg_color;
}

/* small buttons on the nemo status bar */

.nemo-window widget .toolbar button {
    padding: 0 5px;
}

.nemo-window widget .toolbar {
    padding: 0 6px 0 6px;
}

/* provides theming for the rename entries */

.nemo-window .nemo-window-pane widget.entry {
    background-clip: padding-box;
    min-height: 28px;
    padding-left: 4px;
    padding-right: 4px;
    color: @theme_text_color;
    border: 1px solid shade(@button_border, 0.9);
    border-radius: 3px;
    box-shadow: inset 0 1px alpha(black, 0.1),
                inset 1px 0 alpha(black, 0.04),
                inset -1px 0 alpha(black, 0.04),
                inset 0 -1px alpha(black, 0.02),
                0 1px alpha(white, 0.4);
}

.nemo-window .nemo-window-pane widget.entry:selected {
    background-color: @theme_selected_bg_color;
    color: @theme_selected_fg_color;
}

.nemo-window .nemo-window-pane notebook > header {
    padding: 0px;
    margin-right: -2px;
    margin-bottom: -1px;
}

.nemo-window .nemo-window-pane notebook > header > tabs > tab:checked {
    background-color: @theme_base_color;
    margin-bottom: 1px;
}

.nemo-window .nemo-window-pane > notebook box.vertical > overlay > scrolledwindow.view,
.nemo-window .nemo-window-pane > notebook box.vertical > overlay > scrolledwindow > treeview.view {
    background-color: @theme_base_color;
    border: 1px solid @border;
}

.nemo-window toolbar.primary-toolbar {
    margin-bottom: -1px;
}

/*********************
 * Cinnamon Settings *
 *********************/

.cs-header {
    padding: 6px;
    background-color: transparent;
    background-image: linear-gradient(to bottom,
                            @toolbar_bg_a,
                            @toolbar_bg_b);
    border-bottom: 1px solid @border;
}

.cs-category-view,
.cs-category-view .view {
    background-color: transparent;
}
