style "check" 
{
    text[ACTIVE] = @fg_color
    text[SELECTED] = @fg_color
    text[NORMAL] = @fg_color
    
    bg[PRELIGHT] = @bg_color

    engine "pixmap" 
    {
        # Check
        
        image
        {
            function = CHECK
            state = NORMAL
            shadow = OUT
            overlay_file = "images/check-radio/checkbox-unchecked.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = CHECK
            state = PRELIGHT
            shadow = OUT
            overlay_file = "images/check-radio/checkbox-unchecked.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = CHECK
            state = ACTIVE
            shadow = OUT
            overlay_file = "images/check-radio/checkbox-unchecked.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = CHECK
            state = SELECTED
            shadow = OUT
            overlay_file = "images/check-radio/checkbox-unchecked.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = CHECK
            state = INSENSITIVE
            shadow = OUT
            overlay_file = "images/check-radio/checkbox-unchecked-insensitive.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = CHECK
            recolorable = TRUE
            state = NORMAL
            shadow = IN
            overlay_file = "images/check-radio/checkbox-checked.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = CHECK
            recolorable = TRUE
            state = PRELIGHT
            shadow = IN
            overlay_file = "images/check-radio/checkbox-checked.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = CHECK
            recolorable = TRUE
            state = ACTIVE
            shadow = IN
            overlay_file = "images/check-radio/checkbox-checked.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = CHECK
            recolorable = TRUE
            state = SELECTED
            shadow = IN
            overlay_file = "images/check-radio/checkbox-checked.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = CHECK
            recolorable = TRUE
            state = INSENSITIVE
            shadow = IN
            overlay_file = "images/check-radio/checkbox-checked-insensitive.svg"
            overlay_stretch = FALSE
        }
        
        # Radio
        
        image
        {
            function = OPTION
            state = NORMAL
            shadow = OUT
            overlay_file = "images/check-radio/radio-unselected.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = OPTION
            state = PRELIGHT
            shadow = OUT
            overlay_file = "images/check-radio/radio-unselected.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = OPTION
            state = ACTIVE
            shadow = OUT
            overlay_file = "images/check-radio/radio-unselected.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = OPTION
            state = SELECTED
            shadow = OUT
            overlay_file = "images/check-radio/radio-unselected.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = OPTION
            state = INSENSITIVE
            shadow = OUT
            overlay_file = "images/check-radio/radio-unselected-insensitive.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = OPTION
            recolorable = TRUE
            state = NORMAL
            shadow = IN
            overlay_file = "images/check-radio/radio-selected.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = OPTION
            recolorable = TRUE
            state = PRELIGHT
            shadow = IN
            overlay_file = "images/check-radio/radio-selected.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = OPTION
            recolorable = TRUE
            state = ACTIVE
            shadow = IN
            overlay_file = "images/check-radio/radio-selected.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = OPTION
            recolorable = TRUE
            state = SELECTED
            shadow = IN
            overlay_file = "images/check-radio/radio-selected.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = OPTION
            recolorable = TRUE
            state = INSENSITIVE
            shadow = IN
            overlay_file = "images/check-radio/radio-selected-insensitive.svg"
            overlay_stretch = FALSE
        }
        
        # Remove the colored hover box
        
        image
        {
            function = FLAT_BOX
            recolorable = TRUE
            file = "images/check-radio/checkbg.png"
            border = { 5, 5, 5, 5}
            stretch = TRUE
        }
        
        # Remove the focus line
        
        image
        {
            function = FOCUS
            file = "images/other/null.png"
        }
    }
}
