/*****************
 * Desktop Items *
 *****************/

 @define-color desktop_item_fg #eeeeee;
 @define-color desktop_item_selected_fg @theme_selected_fg_color;
 @define-color desktop_item_text_shadow alpha(black, 0.8);

/*********************
 * Error/Warning/... *
 *********************/
@define-color link_color #4a90d9;
@define-color info_color #9ab87c;
@define-color question_color #55c1ec;
@define-color warning_color #f27e3f;
@define-color error_color #e35d4f;
@define-color success_color #4e9a06;

@define-color infobar_fg_color white;
@define-color infobar_text_shadow alpha(black, 0.3);

/*******
 * OSD *
 *******/

@define-color osd_base #212526;
@define-color osd_fg #ededed;
@define-color osd_bg alpha(@osd_base, 0.8);
@define-color osd_trough_bg shade(@osd_fg, 0.1);