#!/usr/bin/python3

# Mint-X
X_HEX_ACCENTS = ["#9ab87c", "#accd8a"]

x_hex_colors = {}
x_hex_colors["Aqua"] = "#6cabcd"
x_hex_colors["Blue"] = "#5b73c4"
x_hex_colors["Brown"] = "#aa876a"
x_hex_colors["Grey"] = "#9d9d9d"
x_hex_colors["Orange"] = "#db9d61"
x_hex_colors["Pink"] = "#c76199"
x_hex_colors["Purple"] = "#8c6ec9"
x_hex_colors["Red"] = "#c15b58"
x_hex_colors["Sand"] = "#c8ac69"
x_hex_colors["Teal"] = "#5aaa9a"

X_RGB_ACCENTS = ["172, 205, 138", "#accd8a"]

x_rgb_colors = {}
x_rgb_colors["Aqua"] = "108, 171, 205"
x_rgb_colors["Blue"] = "91, 115, 196"
x_rgb_colors["Brown"] = "170, 135, 106"
x_rgb_colors["Grey"] = "157,157,157"
x_rgb_colors["Orange"] = "219, 157, 97"
x_rgb_colors["Pink"] = "199, 97, 153"
x_rgb_colors["Purple"] = "140, 110, 201"
x_rgb_colors["Red"] = "193, 91, 88"
x_rgb_colors["Sand"] = "200, 172, 105"
x_rgb_colors["Teal"] = "90, 170, 154"


# Mint-Y
Y_HEX_ACCENT1 = ["#92b372"]  # BASE
Y_HEX_ACCENT2 = ["#8fa876"]  # DARK
Y_HEX_ACCENT3 = ["#afca95"]  # PRELIGHT/HOVER
Y_HEX_ACCENT4 = ["#779559"]  # PRESSED

y_hex_colors1 = {}
y_hex_colors2 = {}
y_hex_colors3 = {}
y_hex_colors4 = {}

y_hex_colors1["Aqua"] = "#6cabcd"
y_hex_colors2["Aqua"] = "#6aa0bd"
y_hex_colors3["Aqua"] = "#82b3ce"
y_hex_colors4["Aqua"] = "#52819a"

y_hex_colors1["Blue"] = "#5b73c4"
y_hex_colors2["Blue"] = "#596eb5"
y_hex_colors3["Blue"] = "#6e82c6"
y_hex_colors4["Blue"] = "#4b5a8d"

y_hex_colors1["Brown"] = "#aa876a"
y_hex_colors2["Brown"] = "#9c7e65"
y_hex_colors3["Brown"] = "#ad9078"
y_hex_colors4["Brown"] = "#796555"

y_hex_colors1["Grey"] = "#9d9d9d"
y_hex_colors2["Grey"] = "#8f8f8f"
y_hex_colors3["Grey"] = "#a3a3a3"
y_hex_colors4["Grey"] = "#727272"

y_hex_colors1["Orange"] = "#db9d61"
y_hex_colors2["Orange"] = "#cc9560"
y_hex_colors3["Orange"] = "#dcaa7a"
y_hex_colors4["Orange"] = "#a97747"

y_hex_colors1["Pink"] = "#c76199"
y_hex_colors2["Pink"] = "#b85f90"
y_hex_colors3["Pink"] = "#c975a3"
y_hex_colors4["Pink"] = "#924d73"

y_hex_colors1["Purple"] = "#8c6ec9"
y_hex_colors2["Purple"] = "#866cba"
y_hex_colors3["Purple"] = "#9b84cb"
y_hex_colors4["Purple"] = "#6a5497"

y_hex_colors1["Red"] = "#c15b58"
y_hex_colors2["Red"] = "#b35a57"
y_hex_colors3["Red"] = "#d1716f"
y_hex_colors4["Red"] = "#9a4a47"

y_hex_colors1["Sand"] = "#c8ac69"
y_hex_colors2["Sand"] = "#b89f65"
y_hex_colors3["Sand"] = "#c9b27c"
y_hex_colors4["Sand"] = "#947f51"

y_hex_colors1["Teal"] = "#5aaa9a"
y_hex_colors2["Teal"] = "#579c8e"
y_hex_colors3["Teal"] = "#6dbbab"
y_hex_colors4["Teal"] = "#4e8378"
