/**********
 * button *
 **********/

button,
button.flat:hover,
/*GtkComboBox .button,*/
headerbar button.titlebutton.appmenu:hover,
toolbar.inline-toolbar toolbutton > button.flat,
.inline-toolbar toolbutton > button,
.inline-toolbar toolbutton > button.flat,
.mate-panel-menu-bar button:hover {
    background-color: transparent;
    background-image: linear-gradient(to bottom,
                            @button_bg_a,
                            @button_bg_b);
}

button.flat,
button.flat:disabled,
button.sidebar-button,
button.sidebar-button:disabled,
headerbar button.titlebutton,
headerbar button.titlebutton:hover,
headerbar button.titlebutton:active,
headerbar button.titlebutton:checked,
.header-bar.titlebar GtkMenuButton.button.titlebutton,
.mate-panel-menu-bar button {
    background-color: transparent;
    background-image: none;
}

.primary-toolbar .raised button,
.primary-toolbar button.raised {
    background-color: transparent;
    background-image: linear-gradient(to bottom,
                            @button_raised_bg_a,
                            @button_raised_bg_b);
}

.primary-toolbar .raised button:hover,
.primary-toolbar button.raised:hover {
    background-color: transparent;
    background-image: linear-gradient(to bottom,
                            @button_hover_raised_bg_a,
                            @button_hover_raised_bg_b);
}

button:hover {
    background-color: transparent;
    background-image: linear-gradient(to bottom,
                            @button_hover_bg_a,
                            @button_hover_bg_b);
}

button:active,
button:checked,
headerbar button.titlebutton.appmenu:active,
headerbar button.titlebutton.appmenu:checked,
.primary-toolbar .raised button:active,
.primary-toolbar .raised button:checked,
.primary-toolbar button.raised:active,
.primary-toolbar button.raised:checked {
    background-color: transparent;
    background-image: linear-gradient(to bottom,
                            @button_active_bg_a,
                            @button_active_bg_b 30%,
                            @button_active_bg_c);
}

button:active:hover,
button:checked:hover,
headerbar button.titlebutton.appmenu:active:hover,
headerbar button.titlebutton.appmenu:checked:hover,
.primary-toolbar .raised button:active:hover,
.primary-toolbar .raised button:checked:hover,
.primary-toolbar button.raised:active:hover,
.primary-toolbar button.raised:checked:hover {
    background-color: transparent;
    background-image: linear-gradient(to bottom,
                            @button_active_hover_bg_a,
                            @button_active_hover_bg_b 30%,
                            @button_active_hover_bg_c);
}

button:disabled,
.primary-toolbar .raised button:disabled,
.primary-toolbar button.raised:disabled {
    background-color: transparent;
    background-image: linear-gradient(to bottom,
                            @button_insensitive_bg_a,
                            @button_insensitive_bg_b);
}

button:disabled:active,
button:disabled:checked {
    background-color: transparent;
    background-image: linear-gradient(to bottom,
                            @button_insensitive_active_bg_a,
                            @button_insensitive_active_bg_b);
}

/*****************
 * column-header *
 *****************/

treeview.view header button {
    background-color: transparent;
    background-image: linear-gradient(to bottom,
                            @column_header_bg_a,
                            @column_header_bg_b 50%,
                            @column_header_bg_c);
}

/*********
 * entry *
 *********/

entry {
    background-color: @theme_base_color;
    background-image: linear-gradient(to bottom,
                            @entry_bg_a,
                            @entry_bg_b);
}

entry:disabled {
    background-color: @theme_bg_color;
    background-image: none;
}

/**********
 * switch *
 **********/

switch {
    background-color: transparent;
    background-image: linear-gradient(to bottom,
                            @button_active_bg_a,
                            @button_active_bg_b 30%,
                            @button_active_bg_c);
}

switch:checked {
    background-color: transparent;
    background-image: linear-gradient(to bottom,
                            shade(@theme_selected_bg_color, 0.85),
                            shade(@theme_selected_bg_color, 1.05));
}

switch:disabled {
    background-color: @theme_bg_color;
    background-image: none;
}

switch slider {
    background-color: transparent;
    background-image: linear-gradient(to bottom,
                                    @button_bg_a,
                                    @button_bg_b);
}

switch slider:disabled {
    background-color: transparent;
    background-image: linear-gradient(to bottom,
                            @button_insensitive_bg_a,
                            @button_insensitive_bg_b);
}

/***********
 * toolbar *
 ***********/

.primary-toolbar,
.primary-toolbar.toolbar,
headerbar {
    background-color: transparent;
    background-image: linear-gradient(to bottom,
                            @toolbar_bg_a,
                            @toolbar_bg_b);
}

toolbar.inline-toolbar {
    background-color: transparent;
    background-image: linear-gradient(to bottom,
                            @inline_toolbar_bg_a,
                            @inline_toolbar_bg_b);
}
