/****************
 * Thunar *
 ****************/

.thunar .sidebar .view, .thunar .sidebar iconview {
  background-color: #ececec; 
}

.thunar toolbar.horizontal button image, .thunar .horizontal.inline-toolbar button image {
  -gtk-icon-transform: scale(0.9); 
}

/****************
 * Xfce Panel *
 ****************/

.xfce4-panel.panel frame > border {
    border: 0;
}

.xfce4-panel.panel label {
    font-weight: normal;
}

.xfce4-panel.panel button {
  border-radius: 0;
  border: none;
  margin-left: 1px;
}

.xfce4-panel.panel button:hover {
}

.xfce4-panel.panel button:active,
.xfce4-panel.panel button:checked {
    border: none;
}

.xfce4-panel.panel button label,
.xfce4-panel.panel button image {
	border: none;
}
