/* Default Color Scheme */

@define-color theme_bg_color #d6d6d6;
@define-color theme_fg_color #212121;
@define-color theme_base_color #f7f7f7;
@define-color theme_text_color #212121;
@define-color theme_selected_bg_color #9ab87c;
@define-color theme_selected_fg_color #f5f5f5;
@define-color theme_tooltip_bg_color #fbeaa0;
@define-color theme_tooltip_fg_color #212121;

/* Misc Colors */

@define-color insensitive_fg_color shade(@theme_bg_color, 0.6);
@define-color border shade(@theme_bg_color, 0.7);
@define-color internal_element_color shade(@theme_fg_color, 0.7);
@define-color internal_element_prelight shade(@theme_fg_color, 0.9);

/* Buttons */

@define-color button_border #b2b2b2;

@define-color button_bg_a shade(@theme_bg_color, 1.16);
@define-color button_bg_b shade(@theme_bg_color, 0.98);

@define-color button_raised_bg_a shade(@theme_bg_color, 1.2);
@define-color button_raised_bg_b shade(@theme_bg_color, 0.95);

@define-color button_hover_bg_a shade(@theme_bg_color, 1.2);
@define-color button_hover_bg_b shade(@theme_bg_color, 1.02);

@define-color button_hover_raised_bg_a shade(@theme_bg_color, 1.24);
@define-color button_hover_raised_bg_b shade(@theme_bg_color, 0.99);

@define-color button_active_bg_a shade(@theme_bg_color, 0.78);
@define-color button_active_bg_b shade(@theme_bg_color, 0.85);
@define-color button_active_bg_c shade(@theme_bg_color, 0.85);

@define-color button_active_hover_bg_a shade(@theme_bg_color, 0.70);
@define-color button_active_hover_bg_b shade(@theme_bg_color, 0.77);
@define-color button_active_hover_bg_c shade(@theme_bg_color, 0.77);

@define-color button_insensitive_bg_a @theme_bg_color;
@define-color button_insensitive_bg_b shade(@theme_bg_color, 0.95);

@define-color button_insensitive_active_bg_a shade(@theme_bg_color, 0.78);
@define-color button_insensitive_active_bg_b shade(@theme_bg_color, 0.9);

@define-color column_header_bg_a @theme_base_color;
@define-color column_header_bg_b shade(@theme_base_color, 0.96);
@define-color column_header_bg_c @theme_bg_color;

@define-color button_fg @theme_fg_color;
@define-color button_text_shadow alpha(white, 0.4);

/* Entry */

@define-color entry_bg_a shade(@theme_base_color, 0.94);
@define-color entry_bg_b @theme_base_color;

/* Menus */

@define-color menu_bg @theme_base_color;
@define-color menu_fg @theme_fg_color;

/* Notebooks */

@define-color notebook_bg shade(@theme_bg_color, 1.1);
@define-color notebook_tab_bg_a shade(@theme_bg_color, 1.05);
@define-color notebook_tab_bg_b shade(@theme_bg_color, 0.98);

/* Progress Bars */

@define-color progressbar_a shade(@theme_selected_bg_color, 1.15);
@define-color progressbar_b shade(@theme_selected_bg_color, 0.95);
@define-color progressbar_border shade(@theme_selected_bg_color, 0.7);
@define-color progressbar_trough_a shade(@theme_bg_color, 0.95);
@define-color progressbar_trough_b shade(@theme_bg_color, 1.15);

/* Scale */

@define-color scale_slider_a shade(@theme_bg_color, 1.2);
@define-color scale_slider_b shade(@theme_bg_color, 1.05);
@define-color scale_slider_hover_a shade(@theme_bg_color, 1.15);
@define-color scale_slider_hover_b shade(@theme_bg_color, 0.95);
@define-color scale_slider_insensitive_a shade(@theme_bg_color, 1.05);
@define-color scale_slider_insensitive_b shade(@theme_bg_color, 0.9);
@define-color scale_trough_a shade(@theme_bg_color, 0.8);
@define-color scale_trough_b @theme_bg_color;
@define-color scale_fill_a shade(@theme_selected_bg_color, 1.1);
@define-color scale_fill_b shade(@theme_selected_bg_color, 0.94);

/* Scrollbars */

@define-color scroll_trough_border shade(@theme_bg_color, 0.8);
@define-color scroll_trough_a alpha(black, 0.15);
@define-color scroll_trough_b alpha(black, 0.05);
@define-color scroll_slider_a shade(@theme_bg_color, 1.1);
@define-color scroll_slider_b shade(@theme_bg_color, 1.02);
@define-color scroll_slider_c shade(@theme_bg_color, 0.96);

/* Toolbars */

@define-color toolbar_bg_a @theme_bg_color;
@define-color toolbar_bg_b shade(@theme_bg_color, 0.88);

@define-color inline_toolbar_bg_a shade(@theme_bg_color, 0.93);
@define-color inline_toolbar_bg_b @theme_bg_color;

/* Views */

@define-color iconview_selected_a shade(@theme_selected_bg_color, 0.9);
@define-color iconview_selected_b shade(@theme_selected_bg_color, 1.1);

@define-color floating_bar_a shade(@theme_bg_color, 1.2);
@define-color floating_bar_b shade(@theme_bg_color, 0.9);
@define-color sidebar_bg shade(@theme_base_color, 0.95);

@import url("gtk-main-common.css");
@import url("gtk-widgets.css");
@import url("gtk-widgets-borders.css");
@import url("gtk-widgets-backgrounds.css");
@import url("gtk-widgets-assets.css");
@import url("apps/gnome-applications.css");
@import url("apps/cinnamon-applications.css");
@import url("apps/mate-applications.css");
@import url("apps/xfce-applications.css");
@import url("apps/ubiquity.css");
@import url("apps/lightdm-gtk-greeter.css");
@import url("apps/lightdm-unity-greeter.css");
